@@ -1,7 +1,7 @@
+#define QT_FEATURE_shared 1
 #define QT_FEATURE_cross_compile -1
 #define QT_FEATURE_framework -1
 #define QT_FEATURE_rpath -1
-#define QT_FEATURE_shared 1
 #define QT_FEATURE_appstore_compliant -1
 #define QT_FEATURE_debug_and_release -1
 #define QT_FEATURE_simulator_and_device -1
@@ -9,6 +9,7 @@
 #define QT_FEATURE_c__11 1
 #define QT_FEATURE_c__14 1
 #define QT_FEATURE_c__1z 1
+#define QT_FEATURE_c__2a -1
 #define QT_FEATURE_c99 1
 #define QT_FEATURE_c11 1
 #define QT_FEATURE_thread 1
@@ -19,8 +20,9 @@
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_VISIBILITY_AVAILABLE true
 #define QT_FEATURE_separate_debug_info -1
+#define QT_FEATURE_signaling_nan 1
 #define QT_FEATURE_static -1
-#define QT_VERSION_STR "5.12.0"
+#define QT_VERSION_STR "5.14.2"
 #define QT_VERSION_MAJOR 5
-#define QT_VERSION_MINOR 12
-#define QT_VERSION_PATCH 0
+#define QT_VERSION_MINOR 14
+#define QT_VERSION_PATCH 2
